# Handle all stdin/stdout with reading, writing, flushing, and try to build interactive commands
# https://python-prompt-toolkit.readthedocs.io/en/master/pages/getting_started.html


class ConsolePipe:

    pass